@@ -1,7 +1,7 @@
 /**************************************************************************
 * Extensible SQLite driver for Qt4/Qt5
 * Copyright (C) 2011-2012 Michał Męciński
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1
@@ -57,9 +57,8 @@ static void regexpFunction( sqlite3_context* context, int /*argc*/, sqlite3_valu
   QString string1 = QString::fromRawData( reinterpret_cast<const QChar*>( data1 ), len1 / sizeof( QChar ) );
   QString string2 = QString::fromRawData( reinterpret_cast<const QChar*>( data2 ), len2 / sizeof( QChar ) );
 
-  QzRegExp pattern( string1.toUpper(), Qt::CaseInsensitive);
-
-  int pos = pattern.indexIn( string2.toUpper() );
+  QzRegExp pattern( string1, Qt::CaseInsensitive);
+  int pos = pattern.indexIn( string2 );
 
   sqlite3_result_int( context, (pos > -1) ? 1 : 0 );
 }
