@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -47,13 +47,15 @@
 #include <QInputDialog>
 
 AdBlockDialog::AdBlockDialog(QWidget* parent)
-  : QWidget(parent)
+  : QDialog(parent)
   , m_manager(AdBlockManager::instance())
   , m_currentTreeWidget(0)
   , m_currentSubscription(0)
   , m_loaded(false)
   , m_useLimitedEasyList(false)
 {
+  setModal(true);
+  setWindowFlags (windowFlags() & ~Qt::WindowContextHelpButtonHint);
   setAttribute(Qt::WA_DeleteOnClose);
   setupUi(this);
 
