@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 /* ============================================================
 * QupZilla - WebKit based browser
@@ -30,7 +30,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 /**
  * Copyright (c) 2009, Zsombor Gegesy <gzsombor@gmail.com>
@@ -63,6 +63,7 @@
 
 #include "adblockrule.h"
 #include "adblocksubscription.h"
+#include "common.h"
 
 #include <QDebug>
 #include <QUrl>
@@ -86,24 +87,24 @@ static QString toSecondLevelDomain(const QUrl &url)
 
   QString domain = urlHost.left(urlHost.size() - topLevelDomain.size());
 
-  if (domain.count(QLatin1Char('.')) == 0) {
+  if (domain.count(QL1C('.')) == 0) {
     return urlHost;
   }
 
-  while (domain.count(QLatin1Char('.')) != 0) {
-    domain = domain.mid(domain.indexOf(QLatin1Char('.')) + 1);
+  while (domain.count(QL1C('.')) != 0) {
+    domain = domain.mid(domain.indexOf(QL1C('.')) + 1);
   }
 
   return domain + topLevelDomain;
 #else
   QString domain = url.host();
 
-  if (domain.count(QLatin1Char('.')) == 0) {
+  if (domain.count(QL1C('.')) == 0) {
     return QString();
   }
 
-  while (domain.count(QLatin1Char('.')) != 1) {
-    domain = domain.mid(domain.indexOf(QLatin1Char('.')) + 1);
+  while (domain.count(QL1C('.')) != 1) {
+    domain = domain.mid(domain.indexOf(QL1C('.')) + 1);
   }
 
   return domain;
@@ -122,6 +123,36 @@ AdBlockRule::AdBlockRule(const QString &filter, AdBlockSubscription* subscriptio
   setFilter(filter);
 }
 
+AdBlockRule::~AdBlockRule()
+{
+  delete m_regExp;
+}
+
+AdBlockRule* AdBlockRule::copy() const
+{
+  AdBlockRule* rule = new AdBlockRule();
+  rule->m_subscription = m_subscription;
+  rule->m_type = m_type;
+  rule->m_options = m_options;
+  rule->m_exceptions = m_exceptions;
+  rule->m_filter = m_filter;
+  rule->m_matchString = m_matchString;
+  rule->m_caseSensitivity = m_caseSensitivity;
+  rule->m_isEnabled = m_isEnabled;
+  rule->m_isException = m_isException;
+  rule->m_isInternalDisabled = m_isInternalDisabled;
+  rule->m_allowedDomains = m_allowedDomains;
+  rule->m_blockedDomains = m_blockedDomains;
+
+  if (m_regExp) {
+    rule->m_regExp = new RegExp;
+    rule->m_regExp->regExp = m_regExp->regExp;
+    rule->m_regExp->matchers = m_regExp->matchers;
+  }
+
+  return rule;
+}
+
 AdBlockSubscription* AdBlockRule::subscription() const
 {
   return m_subscription;
@@ -150,7 +181,7 @@ bool AdBlockRule::isCssRule() const
 
 QString AdBlockRule::cssSelector() const
 {
-  return m_cssSelector;
+  return m_matchString;
 }
 
 bool AdBlockRule::isDocument() const
@@ -175,7 +206,7 @@ bool AdBlockRule::isException() const
 
 bool AdBlockRule::isComment() const
 {
-  return m_filter.startsWith(QLatin1Char('!'));
+  return m_filter.startsWith(QL1C('!'));
 }
 
 bool AdBlockRule::isEnabled() const
@@ -232,7 +263,7 @@ bool AdBlockRule::networkMatch(const QNetworkRequest &request, const QString &do
       return false;
     }
 
-    matched = (m_regExp->indexIn(encodedUrl) != -1);
+    matched = (m_regExp->regExp.indexIn(encodedUrl) != -1);
   }
 
   if (matched) {
@@ -331,7 +362,7 @@ bool AdBlockRule::matchThirdParty(const QNetworkRequest &request) const
 
 bool AdBlockRule::matchObject(const QNetworkRequest &request) const
 {
-  bool match = request.attribute(QNetworkRequest::Attribute(QNetworkRequest::User + 150)).toString() == QLatin1String("object");
+  bool match = request.attribute(QNetworkRequest::Attribute(QNetworkRequest::User + 150)).toString() == QL1S("object");
 
   return hasException(ObjectOption) ? !match : match;
 }
@@ -362,10 +393,10 @@ bool AdBlockRule::matchXmlHttpRequest(const QNetworkRequest &request) const
 
 bool AdBlockRule::matchImage(const QString &encodedUrl) const
 {
-  bool match = encodedUrl.endsWith(QLatin1String(".png")) ||
-      encodedUrl.endsWith(QLatin1String(".jpg")) ||
-      encodedUrl.endsWith(QLatin1String(".gif")) ||
-      encodedUrl.endsWith(QLatin1String(".jpeg"));
+  bool match = encodedUrl.endsWith(QL1S(".png")) ||
+      encodedUrl.endsWith(QL1S(".jpg")) ||
+      encodedUrl.endsWith(QL1S(".gif")) ||
+      encodedUrl.endsWith(QL1S(".jpeg"));
 
   return hasException(ImageOption) ? !match : match;
 }
@@ -375,7 +406,7 @@ void AdBlockRule::parseFilter()
   QString parsedLine = m_filter;
 
   // Empty rule or just comment
-  if (m_filter.trimmed().isEmpty() || m_filter.startsWith(QLatin1Char('!'))) {
+  if (m_filter.trimmed().isEmpty() || m_filter.startsWith(QL1C('!'))) {
     // We want to differentiate rule disabled by user and rule disabled in subscription file
     // m_isInternalDisabled is also used when rule is disabled due to all options not being supported
     m_isEnabled = false;
@@ -385,77 +416,78 @@ void AdBlockRule::parseFilter()
   }
 
   // CSS Element hiding rule
-  if (parsedLine.contains(QLatin1String("##"))) {
+  if (parsedLine.contains(QL1S("##")) || parsedLine.contains(QL1S("#@#"))) {
     m_type = CssRule;
-    int pos = parsedLine.indexOf(QLatin1String("##"));
+    int pos = parsedLine.indexOf(QL1C('#'));
 
     // Domain restricted rule
-    if (!parsedLine.startsWith(QLatin1String("##"))) {
+    if (!parsedLine.startsWith(QL1S("##"))) {
       QString domains = parsedLine.left(pos);
-      parseDomains(domains, QLatin1Char(','));
+      parseDomains(domains, QL1C(','));
     }
 
-    m_cssSelector = parsedLine.mid(pos + 2);
+    m_isException = parsedLine.at(pos + 1) == QL1C('@');
+    m_matchString = parsedLine.mid(m_isException ? pos + 3 : pos + 2);
 
     // CSS rule cannot have more options -> stop parsing
     return;
   }
 
   // Exception always starts with @@
-  if (parsedLine.startsWith(QLatin1String("@@"))) {
+  if (parsedLine.startsWith(QL1S("@@"))) {
     m_isException = true;
     parsedLine = parsedLine.mid(2);
   }
 
   // Parse all options following $ char
-  int optionsIndex = parsedLine.indexOf(QLatin1Char('$'));
+  int optionsIndex = parsedLine.indexOf(QL1C('$'));
   if (optionsIndex >= 0) {
-    QStringList options = parsedLine.mid(optionsIndex + 1).split(QLatin1Char(','), QString::SkipEmptyParts);
+    const QStringList options = parsedLine.mid(optionsIndex + 1).split(QL1C(','), QString::SkipEmptyParts);
 
     int handledOptions = 0;
     foreach (const QString &option, options) {
-      if (option.startsWith(QLatin1String("domain="))) {
-        parseDomains(option.mid(7), QLatin1Char('|'));
+      if (option.startsWith(QL1S("domain="))) {
+        parseDomains(option.mid(7), QL1C('|'));
         ++handledOptions;
       }
-      else if (option == QLatin1String("match-case")) {
+      else if (option == QL1S("match-case")) {
         m_caseSensitivity = Qt::CaseSensitive;
         ++handledOptions;
       }
-      else if (option.endsWith(QLatin1String("third-party"))) {
+      else if (option.endsWith(QL1S("third-party"))) {
         setOption(ThirdPartyOption);
-        setException(ThirdPartyOption, option.startsWith(QLatin1Char('~')));
+        setException(ThirdPartyOption, option.startsWith(QL1C('~')));
         ++handledOptions;
       }
-      else if (option.endsWith(QLatin1String("object"))) {
+      else if (option.endsWith(QL1S("object"))) {
         setOption(ObjectOption);
-        setException(ObjectOption, option.startsWith(QLatin1Char('~')));
+        setException(ObjectOption, option.startsWith(QL1C('~')));
         ++handledOptions;
       }
-      else if (option.endsWith(QLatin1String("subdocument"))) {
+      else if (option.endsWith(QL1S("subdocument"))) {
         setOption(SubdocumentOption);
-        setException(SubdocumentOption, option.startsWith(QLatin1Char('~')));
+        setException(SubdocumentOption, option.startsWith(QL1C('~')));
         ++handledOptions;
       }
-      else if (option.endsWith(QLatin1String("xmlhttprequest"))) {
+      else if (option.endsWith(QL1S("xmlhttprequest"))) {
         setOption(XMLHttpRequestOption);
-        setException(XMLHttpRequestOption, option.startsWith(QLatin1Char('~')));
+        setException(XMLHttpRequestOption, option.startsWith(QL1C('~')));
         ++handledOptions;
       }
-      else if (option.endsWith(QLatin1String("image"))) {
+      else if (option.endsWith(QL1S("image"))) {
         setOption(ImageOption);
-        setException(ImageOption, option.startsWith(QLatin1Char('~')));
+        setException(ImageOption, option.startsWith(QL1C('~')));
         ++handledOptions;
       }
-      else if (option == QLatin1String("document") && m_isException) {
+      else if (option == QL1S("document") && m_isException) {
         setOption(DocumentOption);
         ++handledOptions;
       }
-      else if (option == QLatin1String("elemhide") && m_isException) {
+      else if (option == QL1S("elemhide") && m_isException) {
         setOption(ElementHideOption);
         ++handledOptions;
       }
-      else if (option == QLatin1String("collapse")) {
+      else if (option == QL1S("collapse")) {
         // Hiding placeholders of blocked elements is enabled by default
         ++handledOptions;
       }
@@ -472,27 +504,28 @@ void AdBlockRule::parseFilter()
   }
 
   // Rule is classic regexp
-  if (parsedLine.startsWith(QLatin1Char('/')) && parsedLine.endsWith(QLatin1Char('/'))) {
+  if (parsedLine.startsWith(QL1C('/')) && parsedLine.endsWith(QL1C('/'))) {
     parsedLine = parsedLine.mid(1);
     parsedLine = parsedLine.left(parsedLine.size() - 1);
 
     m_type = RegExpMatchRule;
-    m_regExp = new QRegExp(parsedLine, m_caseSensitivity);
+    m_regExp = new RegExp;
+    m_regExp->regExp = QzRegExp(parsedLine, m_caseSensitivity);
+    m_regExp->matchers = createStringMatchers(parseRegExpFilter(parsedLine));
     return;
   }
 
   // Remove starting and ending wildcards (*)
-  if (parsedLine.startsWith(QLatin1Char('*'))) {
+  if (parsedLine.startsWith(QL1C('*'))) {
     parsedLine = parsedLine.mid(1);
   }
 
-  if (parsedLine.endsWith(QLatin1Char('*'))) {
+  if (parsedLine.endsWith(QL1C('*'))) {
     parsedLine = parsedLine.left(parsedLine.size() - 1);
   }
 
   // We can use fast string matching for domain here
-  if (parsedLine.startsWith(QLatin1String("||")) && parsedLine.endsWith(QLatin1Char('^'))
-      && !parsedLine.contains(QRegExp("[/:?=&\\*]"))) {
+  if (filterIsOnlyDomain(parsedLine)) {
     parsedLine = parsedLine.mid(2);
     parsedLine = parsedLine.left(parsedLine.size() - 1);
 
@@ -502,8 +535,7 @@ void AdBlockRule::parseFilter()
   }
 
   // If rule contains only | at end, we can also use string matching
-  if (parsedLine.endsWith(QLatin1Char('|')) && !parsedLine.contains(QRegExp("[\\^\\*]"))
-      && parsedLine.count(QLatin1Char('|')) == 1) {
+  if (filterIsOnlyEndsMatch(parsedLine)) {
     parsedLine = parsedLine.left(parsedLine.size() - 1);
 
     m_type = StringEndsMatchRule;
@@ -513,26 +545,14 @@ void AdBlockRule::parseFilter()
 
   // If we still find a wildcard (*) or separator (^) or (|)
   // we must modify parsedLine to comply with QzRegExp
-  if (parsedLine.contains(QLatin1Char('*')) || parsedLine.contains(QLatin1Char('^'))
-      || parsedLine.contains(QLatin1Char('|'))) {
-    QString parsedRegExp = parsedLine;
-
-    parsedRegExp.replace(QRegExp(QLatin1String("\\*+")), QLatin1String("*"))       // remove multiple wildcards
-        .replace(QRegExp(QLatin1String("\\^\\|$")), QLatin1String("^"))    // remove anchors following separator placeholder
-        .replace(QRegExp(QLatin1String("^(\\*)")), QString())      // remove leading wildcards
-        .replace(QRegExp(QLatin1String("(\\*)$")), QString())
-        .replace(QRegExp(QLatin1String("(\\W)")), QLatin1String("\\\\1"))  // escape special symbols
-        .replace(QRegExp(QLatin1String("^\\\\\\|\\\\\\|")),
-                 QLatin1String("^[\\w\\-]+:\\/+(?!\\/)(?:[^\\/]+\\.)?"))   // process extended anchor at expression start
-        .replace(QRegExp(QLatin1String("\\\\\\^")),
-                 QLatin1String("(?:[^\\w\\d\\-.%]|$)"))                    // process separator placeholders
-        .replace(QRegExp(QLatin1String("^\\\\\\|")), QLatin1String("^"))   // process anchor at expression start
-        .replace(QRegExp(QLatin1String("\\\\\\|$")), QLatin1String("$"))   // process anchor at expression end
-        .replace(QRegExp(QLatin1String("\\\\\\*")), QLatin1String(".*"));  // replace wildcards by .*
-
+  if (parsedLine.contains(QL1C('*')) ||
+      parsedLine.contains(QL1C('^')) ||
+      parsedLine.contains(QL1C('|'))
+      ) {
     m_type = RegExpMatchRule;
-    m_regExpStrings = parseRegExpFilter(parsedLine);
-    m_regExp = new QRegExp(parsedRegExp, m_caseSensitivity);
+    m_regExp = new RegExp;
+    m_regExp->regExp = QzRegExp(createRegExpFromFilter(parsedLine), m_caseSensitivity);
+    m_regExp->matchers = createStringMatchers(parseRegExpFilter(parsedLine));
     return;
   }
 
@@ -549,7 +569,7 @@ void AdBlockRule::parseDomains(const QString &domains, const QChar &separator)
     if (domain.isEmpty()) {
       continue;
     }
-    if (domain.startsWith(QLatin1Char('~'))) {
+    if (domain.startsWith(QL1C('~'))) {
       m_blockedDomains.append(domain.mid(1));
     }
     else {
@@ -562,26 +582,123 @@ void AdBlockRule::parseDomains(const QString &domains, const QChar &separator)
   }
 }
 
+bool AdBlockRule::filterIsOnlyDomain(const QString &filter) const
+{
+  if (!filter.endsWith(QL1C('^')) || !filter.startsWith(QL1S("||")))
+    return false;
+
+  for (int i = 0; i < filter.size(); ++i) {
+    switch (filter.at(i).toLatin1()) {
+    case '/':
+    case ':':
+    case '?':
+    case '=':
+    case '&':
+    case '*':
+      return false;
+    default:
+      break;
+    }
+  }
+
+  return true;
+}
+
+bool AdBlockRule::filterIsOnlyEndsMatch(const QString &filter) const
+{
+  for (int i = 0; i < filter.size(); ++i) {
+    switch (filter.at(i).toLatin1()) {
+    case '^':
+    case '*':
+      return false;
+    case '|':
+      return i == filter.size() - 1;
+    default:
+      break;
+    }
+  }
+
+  return false;
+}
+
+static bool wordCharacter(const QChar &c)
+{
+  return c.isLetterOrNumber() || c.isMark() || c == QL1C('_');
+}
+
+QString AdBlockRule::createRegExpFromFilter(const QString &filter) const
+{
+  QString parsed;
+  parsed.reserve(filter.size());
+
+  bool hadWildcard = false; // Filter multiple wildcards
+
+  for (int i = 0; i < filter.size(); ++i) {
+    const QChar c = filter.at(i);
+    switch (c.toLatin1()) {
+    case '^':
+      parsed.append(QL1S("(?:[^\\w\\d\\-.%]|$)"));
+      break;
+
+    case '*':
+      if (!hadWildcard)
+        parsed.append(QL1S(".*"));
+      break;
+
+    case '|':
+      if (i == 0) {
+        if (filter.size() > 1 && filter.at(1) == QL1C('|')) {
+          parsed.append(QL1S("^[\\w\\-]+:\\/+(?!\\/)(?:[^\\/]+\\.)?"));
+          i++;
+        }
+        else {
+          parsed.append('^');
+        }
+        break;
+      }
+      else if (i == filter.size() - 1) {
+        parsed.append(QL1C('$'));
+        break;
+      }
+      // fallthrough
+
+    default:
+      if (!wordCharacter(c))
+        parsed.append(QL1C('\\') + c);
+      else
+        parsed.append(c);
+    }
+
+    hadWildcard = c == QL1C('*');
+  }
+
+  return parsed;
+}
+
+QList<QStringMatcher> AdBlockRule::createStringMatchers(const QStringList &filters) const
+{
+  QList<QStringMatcher> matchers;
+  matchers.reserve(filters.size());
+
+  foreach (const QString &filter, filters) {
+    matchers.append(QStringMatcher(filter, m_caseSensitivity));
+  }
+
+  return matchers;
+}
+
 bool AdBlockRule::isMatchingDomain(const QString &domain, const QString &filter) const
 {
-  if (filter == domain) {
-    return true;
-  }
-
-  if (!domain.endsWith(filter)) {
-    return false;
-  }
-
-  int index = domain.indexOf(filter);
-  return index > 0 && domain[index - 1] == QLatin1Char('.');
+  return Common::matchDomain(filter, domain);
 }
 
 bool AdBlockRule::isMatchingRegExpStrings(const QString &url) const
 {
-  foreach (const QString &string, m_regExpStrings) {
-    if (!url.contains(string)) {
+  Q_ASSERT(m_regExp);
+
+  foreach (const QStringMatcher &matcher, m_regExp->matchers) {
+    if (matcher.indexIn(url) == -1)
       return false;
-    }
   }
 
   return true;
@@ -589,22 +706,28 @@ bool AdBlockRule::isMatchingRegExpStrings(const QString &url) const
 
 // Split regexp filter into strings that can be used with QString::contains
 // Don't use parts that contains only 1 char and duplicated parts
-QStringList AdBlockRule::parseRegExpFilter(const QString &parsedFilter) const
+QStringList AdBlockRule::parseRegExpFilter(const QString &filter) const
 {
-  // Meta characters in AdBlock rules are | * ^
-  QStringList list = parsedFilter.split(QRegExp("[|\\*\\^]"), QString::SkipEmptyParts);
+  QStringList list;
+  int startPos = -1;
 
-  list.removeDuplicates();
-
-  for (int i = 0; i < list.length(); ++i) {
-    const QString part = list.at(i);
-
-    if (part.length() < 2) {
-      list.removeAt(i);
-      i--;
+  for (int i = 0; i < filter.size(); ++i) {
+    const QChar c = filter.at(i);
+    // Meta characters in AdBlock rules are | * ^
+    if (c == QL1C('|') || c == QL1C('*') || c == QL1C('^')) {
+      const QString sub = filter.mid(startPos, i - startPos);
+      if (sub.size() > 1)
+        list.append(sub);
+      startPos = i + 1;
     }
   }
 
+  const QString sub = filter.mid(startPos);
+  if (sub.size() > 1)
+    list.append(sub);
+
+  list.removeDuplicates();
+
   return list;
 }
 
@@ -629,8 +752,3 @@ void AdBlockRule::setException(const AdBlockRule::RuleOption &opt, bool on)
     m_exceptions |= opt;
   }
 }
-
-AdBlockRule::~AdBlockRule()
-{
-  delete m_regExp;
-}
