@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -664,16 +664,16 @@ void AddFeedWizard::finish()
                  "displayEmbeddedImages = ?, displayNews = ?, layoutDirection = ?, "
                  "javaScriptEnable = ? "
                  "WHERE id == ?");
-      q1.addBindValue(q.value(0).toString());
-      q1.addBindValue(q.value(1).toInt());
-      q1.addBindValue(q.value(2).toInt());
-      q1.addBindValue(q.value(3).toInt());
-      q1.addBindValue(q.value(4).toInt());
-      q1.addBindValue(q.value(5).toInt());
-      q1.addBindValue(q.value(6).toInt());
-      q1.addBindValue(q.value(7).toInt());
-      q1.addBindValue(q.value(8).toInt());
-      q1.addBindValue(q.value(9).toInt());
+      q1.addBindValue(q.value(0));
+      q1.addBindValue(q.value(1));
+      q1.addBindValue(q.value(2));
+      q1.addBindValue(q.value(3));
+      q1.addBindValue(q.value(4));
+      q1.addBindValue(q.value(5));
+      q1.addBindValue(q.value(6));
+      q1.addBindValue(q.value(7));
+      q1.addBindValue(q.value(8));
+      q1.addBindValue(q.value(9));
       q1.addBindValue(feedId_);
       q1.exec();
     }
