@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef MAINAPPLICATION_H
 #define MAINAPPLICATION_H
@@ -31,6 +31,7 @@
 #include "cookiejar.h"
 #include "downloadmanager.h"
 #include "mainwindow.h"
+#include "ganalytics.h"
 
 class NetworkManager;
 class SplashScreen;
@@ -50,6 +51,8 @@ public:
   void setClosing();
   bool isClosing() const;
   bool isNoDebugOutput() const { return noDebugOutput_; }
+  void showClosingWidget();
+  bool dataDirInitialized() const { return dataDirInitialized_; }
 
   QString resourcesDir() const;
   QString dataDir() const;
@@ -80,6 +83,12 @@ public:
   void c2fSetWhitelist(QStringList whitelist);
   void c2fAddWhitelist(const QString &site);
 
+  void setTranslateApplication();
+  QString language() const { return langFileName_; }
+  void setLanguage(const QString &lang) { langFileName_ = lang; }
+
+  GAnalytics *analytics() const { return analytics_; }
+
 public slots:
   void receiveMessage(const QString &message);
   void quitApplication();
@@ -96,6 +105,7 @@ private:
   void checkPortable();
   void checkDir();
   void createSettings();
+  void createGoogleAnalytics();
   void connectDatabase();
   void loadSettings();
   void setStyleApplication();
@@ -103,9 +113,12 @@ private:
   void closeSplashScreen();
   void setProgressSplashScreen(int value);
 
+  QUrl userStyleSheet(const QString &filePath) const;
+
   bool isPortable_;
   bool isPortableAppsCom_;
   bool isClosing_;
+  bool dataDirInitialized_;
 
   QString resourcesDir_;
   QString dataDir_;
@@ -120,6 +133,8 @@ private:
   bool updateFeedsStartUp_;
   bool noDebugOutput_;
 
+  QTranslator *translator_;
+  QString langFileName_;
   SplashScreen *splashScreen_;
   MainWindow *mainWindow_;
   NetworkManager *networkManager_;
@@ -127,11 +142,12 @@ private:
   QNetworkDiskCache *diskCache_;
   UpdateFeeds *updateFeeds_;
   DownloadManager *downloadManager_;
+  QWidget *closingWidget_;
 
   QStringList c2fWhitelist_;
   bool c2fEnabled_;
 
-  QUrl userStyleSheet(const QString &filePath) const;
+  GAnalytics *analytics_;
 
 };
 
