@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -162,6 +162,9 @@ public:
   QAction *linkedinShareAct_;
   QAction *bloggerShareAct_;
   QAction *printfriendlyShareAct_;
+  QAction *instapaperShareAct_;
+  QAction *redditShareAct_;
+  QAction *hackerNewsShareAct_;
   QAction *copyLinkAct_;
   QAction *pageUpWebViewAct_;
   QAction *pageDownWebViewAct_;
@@ -264,10 +267,13 @@ public:
   bool showButtonMarkReadNotify_;
   bool showButtonExBrowserNotify_;
   bool showButtonDeleteNotify_;
+  bool closeNotify_;
   QList<int> idFeedsNotifyList_;
 
   AdBlockIcon *adBlockIcon() { return adblockIcon_; }
 
+  void webViewFullScreen(bool on);
+
 public slots:
   void restoreFeedsOnStartUp();
   void addFeed();
@@ -307,6 +313,7 @@ public slots:
   void slotPrintPreview(QWebFrame* frame = 0);
 
 signals:
+  void signalQuitApp();
   void signalPlaceToTray();
   void signalGetFeedTimer(int feedId);
   void signalGetAllFeedsTimer();
@@ -325,7 +332,6 @@ signals:
   void signalNextUpdate(bool finish);
   void signalRecountCategoryCounts();
   void signalRecountFeedCounts(int feedId, bool update = true);
-  void setFeedRead(int readType, int feedId, int idException, QList<int> idNewsList);
   void signalSetFeedRead(int readType, int feedId, int idException, QList<int> idNewsList);
   void signalPlaySoundNewNews();
   void signalUpdateStatus(int feedId, bool changed);
@@ -378,6 +384,8 @@ private slots:
   void slotFeedDownPressed();
   void slotFeedHomePressed();
   void slotFeedEndPressed();
+  void slotFeedPageUpPressed();
+  void slotFeedPageDownPressed();
   void slotFeedPrevious();
   void slotFeedNext();
   void setStyleApp(QAction*);
@@ -524,7 +532,9 @@ private:
   int addTab(NewsTabWidget *widget);
 
   NewsModel *newsModel_;
+#ifndef Q_OS_MAC
   QMenu *mainMenu_;
+#endif
   ToolButton *mainMenuButton_;
   TabBar *tabBar_;
   QWidget *tabBarWidget_;
