@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -193,7 +193,7 @@ CleanUpThread::~CleanUpThread()
   if (!mainApp->storeDBMemory()) {
     db.exec("VACUUM");
   } else {
-    Database::sqliteDBMemFile();
+    Database::sqliteDBMemFile(db);
     Database::setVacuum();
   }
 }
@@ -425,7 +425,7 @@ void CleanUpWizard::feedItemChanged(QTreeWidgetItem *item, int column)
 
 void CleanUpWizard::setCheckStateItem(QTreeWidgetItem *item, Qt::CheckState state)
 {
-  for(int i = 0; i < item->childCount(); ++i) {
+  for (int i = 0; i < item->childCount(); ++i) {
     QTreeWidgetItem *childItem = item->child(i);
     childItem->setCheckState(0, state);
     setCheckStateItem(childItem, state);
@@ -521,7 +521,7 @@ void CleanUpWizard::finishCleanUp()
 
   accept();
 
-  QMessageBox::information(0, tr("Information"),
+  QMessageBox::information(this, tr("Information"),
                            tr("Clean Up wizard deleted %1 news").
                            arg(cleanUpThread_->countDeleted));
 }
