@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -227,18 +227,20 @@ void Database::initialization()
     setPragma(db);
 
     if (mainApp->storeDBMemory()) {
-      sqliteDBMemFile(false);
+      sqliteDBMemFile(db, false);
     }
   }
 }
 
 void Database::setPragma(QSqlDatabase &db)
 {
+  Settings settings;
   QSqlQuery q(db);
   q.setForwardOnly(true);
   q.exec("PRAGMA encoding = \"UTF-8\"");
 
-//  q.exec("PRAGMA synchronous = FULL");
+  QString sync = settings.value("synchronousDB", "FULL").toString();
+  q.exec(QString("PRAGMA synchronous = %1").arg(sync));
 //  q.exec("PRAGMA journal_mode = MEMORY");
 //  q.exec("PRAGMA temp_store = MEMORY");
 
@@ -256,7 +258,7 @@ void Database::prepareDatabase()
       QString message = QString("Cannot open SQLite database! \n"
                                 "Error: %1").arg(db.lastError().text());
       qCritical() << message;
-      QMessageBox::critical(0, QObject::tr("Error"), message);
+      QMessageBox::critical(mainApp->mainWindow(), QObject::tr("Error"), message);
     } else {
       setPragma(db);
       QSqlQuery q(db);
@@ -425,13 +427,13 @@ QSqlDatabase Database::connection(const QString &connectionName)
   return db;
 }
 
-void Database::sqliteDBMemFile(bool save)
+void Database::sqliteDBMemFile(QSqlDatabase &db, bool save)
 {
   if (save) qWarning() << "sqliteDBMemFile(): from memory to file...";
   else qWarning() << "sqliteDBMemFile(): from file to memory...";
 
   int rc = -1;                   /* Function return code */
-  QVariant v = QSqlDatabase::database().driver()->handle();
+  QVariant v = db.driver()->handle();
   if (v.isValid() && qstrcmp(v.typeName(),"sqlite3*") == 0) {
     // v.data() returns a pointer to the handle
     sqlite3 *handle = *static_cast<sqlite3 **>(v.data());
@@ -482,9 +484,9 @@ void Database::sqliteDBMemFile(bool save)
             qDebug() << rc << "backup" << pagecount << "remain" << remaining;
           }
 
-          if((rc == SQLITE_OK) || (rc == SQLITE_BUSY) || (rc == SQLITE_LOCKED))
+          if ((rc == SQLITE_OK) || (rc == SQLITE_BUSY) || (rc == SQLITE_LOCKED))
             sqlite3_sleep(100);
-        } while((rc == SQLITE_OK) || (rc == SQLITE_BUSY) || (rc == SQLITE_LOCKED));
+        } while ((rc == SQLITE_OK) || (rc == SQLITE_BUSY) || (rc == SQLITE_LOCKED));
 
         /* Release resources allocated by backup_init(). */
         (void)sqlite3_backup_finish(pBackup);
