@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "downloadmanager.h"
 
@@ -21,6 +21,10 @@
 #include "networkmanager.h"
 #include "authenticationdialog.h"
 #include "downloaditem.h"
+#include "settings.h"
+#include "common.h"
+
+#include <qzregexp.h>
 
 DownloadManager::DownloadManager(QWidget *parent)
   : QWidget(parent)
@@ -77,17 +81,27 @@ void DownloadManager::download(const QNetworkRequest &request)
 
 void DownloadManager::handleUnsupportedContent(QNetworkReply* reply, bool askDownloadLocation)
 {
+  Settings settings;
+  QString downloadLocation = mainApp->mainWindow()->downloadLocation_;
+  if (askDownloadLocation || !QFile::exists(downloadLocation))
+    downloadLocation = settings.value("Settings/curDownloadLocation", downloadLocation).toString();
+
   QString fileName(getFileName(reply));
-  fileName = mainApp->mainWindow()->downloadLocation_ + "/" + fileName;
+  fileName = Common::ensureUniqueFilename(downloadLocation + "/" + fileName);
   QFileInfo fileInfo(fileName);
   if (askDownloadLocation || fileInfo.exists() ||
-      !QFile::exists(mainApp->mainWindow()->downloadLocation_)) {
+      !QFile::exists(downloadLocation)) {
     QString filter = QString(tr("File %1 (*.%2)") + ";;" + tr("All Files (*.*)")).
         arg(fileInfo.suffix().toUpper()).
         arg(fileInfo.suffix().toLower());
     fileName = QFileDialog::getSaveFileName(mainApp->mainWindow(),
                                             tr("Save As..."),
                                             fileName, filter);
+
+    fileInfo.setFile(fileName);
+    if (!fileName.isEmpty())
+      settings.setValue("Settings/curDownloadLocation", fileInfo.absolutePath());
+
   }
   if (fileName.isNull()) {
     reply->abort();
@@ -107,13 +121,13 @@ QString DownloadManager::getFileName(QNetworkReply* reply)
   if (reply->hasRawHeader("Content-Disposition")) {
     QString value = QString::fromUtf8(reply->rawHeader("Content-Disposition"));
 
-    if (value.contains(QRegExp("filename\\s*\\*\\s*=\\s*UTF-8", Qt::CaseInsensitive))) {
-      QRegExp reg("filename\\s*\\*\\s*=\\s*UTF-8''([^;]*)", Qt::CaseInsensitive);
+    if (value.contains(QzRegExp("filename\\s*\\*\\s*=\\s*UTF-8", Qt::CaseInsensitive))) {
+      QzRegExp reg("filename\\s*\\*\\s*=\\s*UTF-8''([^;]*)", Qt::CaseInsensitive);
       reg.indexIn(value);
       path = QUrl::fromPercentEncoding(reg.cap(1).toUtf8()).trimmed();
     }
-    else if (value.contains(QRegExp("filename\\s*=", Qt::CaseInsensitive))) {
-      QRegExp reg("filename\\s*=([^;]*)", Qt::CaseInsensitive);
+    else if (value.contains(QzRegExp("filename\\s*=", Qt::CaseInsensitive))) {
+      QzRegExp reg("filename\\s*=([^;]*)", Qt::CaseInsensitive);
       reg.indexIn(value);
       path = QUrl::fromPercentEncoding(reg.cap(1).toUtf8()).trimmed();
 
@@ -143,7 +157,7 @@ QString DownloadManager::getFileName(QNetworkReply* reply)
 
   QString name = baseName + endName;
 
-  name.replace(QRegExp("[;:<>?\"]"), "_");
+  name.replace(QzRegExp("[;:<>?\"]"), "_");
 
   return name;
 }
@@ -160,7 +174,8 @@ void DownloadManager::startExternalApp(const QString &executable, const QUrl &ur
     info = info.arg(tr("Executable: "), executable,
                     tr("Arguments: "), arguments.join(QLatin1String(" ")));
 
-    QMessageBox::critical(0, QObject::tr("Cannot start external program"),
+    QMessageBox::critical(this,
+                          QObject::tr("Cannot start external program"),
                           QObject::tr("Cannot start external program! %1").arg(info));
   }
 }
