@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -454,7 +454,7 @@ void FeedPropertiesDialog::selectIcon()
 
   if (fileName.isNull()) return;
 
-  QMessageBox msgBox;
+  QMessageBox msgBox(this);
   msgBox.setText(tr("Load icon: can't open a file!"));
   msgBox.setIcon(QMessageBox::Warning);
 
@@ -531,7 +531,7 @@ FEED_PROPERTIES FeedPropertiesDialog::getFeedProperties()
   feedProperties.authentication.user = user_->text();
   feedProperties.authentication.pass = pass_->text();
 
-  return(feedProperties);
+  return (feedProperties);
 }
 //------------------------------------------------------------------------------
 void FeedPropertiesDialog::setFeedProperties(FEED_PROPERTIES properties)
