@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "newsfiltersdialog.h"
 
@@ -254,7 +254,7 @@ void NewsFiltersDialog::editFilter()
 
 void NewsFiltersDialog::deleteFilter()
 {
-  QMessageBox msgBox;
+  QMessageBox msgBox(this);
   msgBox.setIcon(QMessageBox::Question);
   msgBox.setWindowTitle(tr("Delete Filter"));
   msgBox.setText(QString(tr("Are you sure you want to delete the filter '%1'?")).
