@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -210,7 +210,6 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
     else {
       while (q.next()) {
         QString str = q.value(2).toString();
-        if (!str.isEmpty()) {
         titleList_.append(str);
 
         str = q.value(1).toString();
@@ -220,7 +219,6 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
         publishedList_.append(str);
         str = q.value(4).toString();
         linkList_.append(str);
-        }
       }
     }
     q.finish();
@@ -350,6 +348,15 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
     } else {
       newsItem.content = nodeContent.toElement().text();
     }
+    if (newsItem.content.isEmpty()) {
+      nodeContent = newsList.item(i).namedItem("media:group");
+      if (!nodeContent.isNull()) {
+        QString description = nodeContent.namedItem("media:description").toElement().text();
+        QString media = nodeContent.namedItem("media:thumbnail").toElement().attribute("url");
+        newsItem.content += "<p class=\"description\">" + description + "</p>";
+        newsItem.content += "<img src=\"" + media + "\" alt=\"image\"/>";
+      }
+    }
     if (!(newsItem.content.isEmpty() ||
           (newsItem.description.length() > newsItem.content.length()))) {
       newsItem.description = newsItem.content;
@@ -429,7 +436,7 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
             if (publishedList_.at(i) == newsItem->updated)
               isDuplicate = true;
           } else {                      // ... or by title
-            if (titleList_.at(i) == newsItem->title)
+            if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
               isDuplicate = true;
           }
         }
@@ -439,7 +446,7 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
         if (publishedList_.at(i) == newsItem->updated)
           isDuplicate = true;
       } else {                              // ... or by title
-        if (titleList_.at(i) == newsItem->title)
+        if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
           isDuplicate = true;
       }
     }
@@ -516,19 +523,34 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
 void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
 {
   QDomNode channel = doc.documentElement().namedItem("channel");
+  if (channel.isNull())
+    channel = doc.documentElement().namedItem("rss:channel");
   FeedItemStruct feedItem;
 
   feedItem.title = toPlainText(channel.namedItem("title").toElement().text());
+  if (feedItem.title.isEmpty())
+    feedItem.title = toPlainText(channel.namedItem("rss:title").toElement().text());
   feedItem.description = channel.namedItem("description").toElement().text();
+  if (feedItem.description.isEmpty())
+    feedItem.description = toPlainText(channel.namedItem("rss:description").toElement().text());
   feedItem.link = toPlainText(channel.namedItem("link").toElement().text());
-  if (QUrl(feedItem.link).host().isEmpty())
-    feedItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host() + feedItem.link;
+  if (feedItem.link.isEmpty())
+    feedItem.link = toPlainText(channel.namedItem("rss:link").toElement().text());
+  QUrl url = QUrl(feedItem.link);
+  if (url.host().isEmpty())
+    url.setHost(QUrl(feedUrl).host());
+  if (url.scheme().isEmpty())
+    url.setScheme(QUrl(feedUrl).scheme());
+  feedItem.link = url.toString();
+
   feedItem.updated = channel.namedItem("pubDate").toElement().text();
   if (feedItem.updated.isEmpty())
     feedItem.updated = channel.namedItem("pubdate").toElement().text();
   feedItem.updated = parseDate(feedItem.updated, feedUrl);
   feedItem.author = toPlainText(channel.namedItem("author").toElement().text());
   feedItem.language = channel.namedItem("language").toElement().text();
+  if (feedItem.language.isEmpty())
+    feedItem.language = channel.namedItem("dc:language").toElement().text();
 
   QSqlQuery q(db_);
   q.setForwardOnly(true);
@@ -547,10 +569,14 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
   q.exec();
 
   QDomNodeList newsList = doc.elementsByTagName("item");
+  if (newsList.isEmpty())
+    newsList = doc.elementsByTagName("rss:item");
   for (int i = 0; i < newsList.size(); i++) {
     NewsItemStruct newsItem;
     newsItem.id = newsList.item(i).namedItem("guid").toElement().text();
     newsItem.title = toPlainText(newsList.item(i).namedItem("title").toElement().text());
+    if (newsItem.title.isEmpty())
+      newsItem.title = toPlainText(newsList.item(i).namedItem("rss:title").toElement().text());
     newsItem.updated = newsList.item(i).namedItem("pubDate").toElement().text();
     if (newsItem.updated.isEmpty())
       newsItem.updated = newsList.item(i).namedItem("pubdate").toElement().text();
@@ -562,11 +588,18 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
       newsItem.author = toPlainText(newsList.item(i).namedItem("dc:creator").toElement().text());
     newsItem.link = toPlainText(newsList.item(i).namedItem("link").toElement().text());
     if (newsItem.link.isEmpty()) {
-      if (newsList.item(i).namedItem("guid").toElement().attribute("isPermaLink") == "true")
-        newsItem.link = newsItem.id;
+        newsItem.link = toPlainText(newsList.item(i).namedItem("rss:link").toElement().text());
+        if (newsItem.link.isEmpty()) {
+            if (newsList.item(i).namedItem("guid").toElement().attribute("isPermaLink") == "true")
+                newsItem.link = newsItem.id;
+        }
     }
-    if (QUrl(newsItem.link).host().isEmpty())
-      newsItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host() + newsItem.link;
+    url = QUrl(newsItem.link);
+    if (url.host().isEmpty())
+      url.setHost(QUrl(feedUrl).host());
+    if (url.scheme().isEmpty())
+      url.setScheme(QUrl(feedUrl).scheme());
+    newsItem.link = url.toString();
 
     newsItem.description = newsList.item(i).namedItem("description").toElement().text();
     newsItem.content = newsList.item(i).namedItem("content:encoded").toElement().text();
@@ -625,7 +658,7 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
             isDuplicate = true;
           }
         } else {                            // ... or by title
-          if (titleList_.at(i) == newsItem->title)
+          if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
             isDuplicate = true;
         }
       }
@@ -649,7 +682,7 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
             isDuplicate = true;
           }
         } else {                            // ... or by title
-          if (titleList_.at(i) == newsItem->title)
+          if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
             isDuplicate = true;
         }
       }
@@ -672,7 +705,7 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
           isDuplicate = true;
         }
       } else {                            // ... or by title
-        if (titleList_.at(i) == newsItem->title)
+        if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
           isDuplicate = true;
       }
       if (!isDuplicate) {
