@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef PARSEOBJECT_H
 #define PARSEOBJECT_H
@@ -77,6 +77,8 @@ public:
   explicit ParseObject(QObject *parent = 0);
   ~ParseObject();
 
+  void disconnectObjects();
+
 public slots:
   void parseXml(QByteArray data, int feedId,
                 QDateTime dtReply, QString codecName);
@@ -94,8 +96,8 @@ private slots:
   void getQueuedXml();
   void slotParse(const QByteArray &xmlData, const int &feedId,
                  const QDateTime &dtReply, const QString &codecName);
-  void addAtomNewsIntoBase(NewsItemStruct &newsItem);
-  void addRssNewsIntoBase(NewsItemStruct &newsItem);
+  void addAtomNewsIntoBase(NewsItemStruct *newsItem);
+  void addRssNewsIntoBase(NewsItemStruct *newsItem);
 
 private:
   void parseAtom(const QString &feedUrl, const QDomDocument &doc);
@@ -117,6 +119,11 @@ private:
   bool duplicateNewsMode_;
   bool feedChanged_;
 
+  QStringList guidList_;
+  QStringList linkList_;
+  QStringList titleList_;
+  QStringList publishedList_;
+
 };
 
 #endif // PARSEOBJECT_H
