@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef UPDATEAPPDIALOG_H
 #define UPDATEAPPDIALOG_H
@@ -23,6 +23,7 @@
 #include <QWebFrame>
 
 #include "dialog.h"
+#include "networkmanagerproxy.h"
 
 class UpdateAppDialog : public Dialog
 {
@@ -31,6 +32,8 @@ public:
   explicit UpdateAppDialog(const QString &lang, QWidget *parent, bool show = true);
   ~UpdateAppDialog();
 
+  void disconnectObjects();
+
 signals:
   void signalNewVersion(const QString &newVersion = QString());
 
@@ -46,6 +49,7 @@ private:
   bool showDialog_;
 
   QWebPage *page_;
+  NetworkManagerProxy *networkManagerProxy_;
   QNetworkReply *reply_;
   QNetworkReply *historyReply_;
 
